@@ -90,6 +90,11 @@ class Browser(object):
         """Callback function used with ProcessHandler to handle output from the browser process."""
         pass
 
+    @abstractmethod
+    def pid(self):
+        """pid of the browser process or None if there is no pid"""
+        pass
+
     @abstractmethod
     def is_alive(self):
         """Boolean indicating whether the browser process is still running"""
@@ -119,6 +124,9 @@ class NullBrowser(Browser):
     def stop(self):
         pass
 
+    def pid(self):
+        return None
+
     def is_alive(self):
         return True
 
